@@ -24,7 +24,7 @@ if __name__ == '__main__':
 
 # TBF: Live JSON Input/Output are not supported yet. (Like PCA Eigen)
 
-@D_General
+
 def AbsPath(path):
     if path.lower().startswith('hdfs://'):
         abspath = path
@@ -44,7 +44,7 @@ def AbsPath(path):
     Log(f'Absolute path of {path} is {abspath}')
     return abspath
 
-@D_General
+# not to have D_General as these function may be called in a wait loop in VEP annotation function
 def GetLocalPath(path, silent=False):
     inPath = path
     if path.lower().startswith('hdfs://'):
@@ -58,11 +58,11 @@ def GetLocalPath(path, silent=False):
         Log(f'Local path of {inPath} is {path}')
     return path
 
+# not to have D_General as these function may be called in a wait loop in VEP annotation function
 def FileExist(path, silent=False):
     path = GetLocalPath(path, silent)
     return os.path.exists(path)
 
-@D_General
 def WildCardPath(path):
     path = GetLocalPath(path)
     fileList = glob.glob(path)
@@ -110,7 +110,6 @@ def HailPath(path):
     else:
         LogException(f'Path must be a list but it is of type {type(path)} and the value is {path}.')
 
-
 @D_General
 def Count(table):
     """Count a Hail Table or MatrixTable.
@@ -136,7 +135,6 @@ def Count(table):
 
     return cnt
 
-
 @D_General
 def SampleRows(mt, subSample):
     """Subsample rows of MatrixTable by a fraction or number of rows.
@@ -176,7 +174,6 @@ def SampleRows(mt, subSample):
     Count(mt)
     return mt
 
-
 @D_General
 def FlattenTable(ht):
     """Recursively flatten table fields including arrays.
@@ -219,14 +216,20 @@ def FlattenTable(ht):
                         LogException(f'Cannot drop {k} from table.')
                     doneFlag = False
                 else:
-                    LogPrint(f'{k} of type {t} can not be flattend beacuase its length is variable min:{minLen} max:{maxLen}.', level='WARNING')
+                    Log(f'{k} of type {t} can not be flattend beacuase its length is variable min:{minLen} max:{maxLen}.', level='WARNING')
+                    Log(f'Variable length array {k} is converted to string with " ~#^#~ " as a seperator', level='WARNING')
+                    expr[k] = hl.str(' ~#^#~ ').join(ht[k])
+                    try:
+                        ht = ht.annotate(**expr)
+                    except:
+                        LogException(f'Cannot perform annotation with expression {expr}.')
 
     Count(ht)
     return ht
 
 
 @D_General
-def ImportMultipleTsv(files, addFileNumber=False):
+def ImportMultipleTable(files, addFileNumber=False):
     """Load multiple tsv files and turn it into a Hail Table
 
     Notes:
